@@ -1,10 +1,10 @@
 import os
 from copy import deepcopy
+from dataclasses import dataclass
 from itertools import chain, starmap
 from types import ModuleType
 from typing import Any, Callable, Dict, List, Tuple
 
-import attr
 from _pytest.config import Config
 from _pytest.mark.structures import Mark
 from vcr import VCR
@@ -12,6 +12,13 @@ from vcr.cassette import CassetteContextDecorator
 from vcr.persisters.filesystem import FilesystemPersister
 from vcr.serialize import deserialize
 
+try:
+    # VCR.py >=5
+    from vcr.cassette import CassetteNotFoundError
+except ImportError:
+    # VCR.py <5
+    CassetteNotFoundError = ValueError
+
 from .utils import unique, unpack
 
 ConfigType = Dict[str, Any]
@@ -26,11 +33,11 @@ def load_cassette(cassette_path: str, serializer: ModuleType) -> Tuple[List, Lis
     return deserialize(cassette_content, serializer)
 
 
-@attr.s(slots=True)
+@dataclass
 class CombinedPersister(FilesystemPersister):
     """Load extra cassettes, but saves only the first one."""
 
-    extra_paths = attr.ib(type=List[str])
+    extra_paths: List[str]
 
     def load_cassette(self, cassette_path: str, serializer: ModuleType) -> Tuple[List, List]:
         all_paths = chain.from_iterable(((cassette_path,), self.extra_paths))
@@ -45,11 +52,10 @@ class CombinedPersister(FilesystemPersister):
         requests, responses = starmap(unpack, zip(*all_content))
         requests, responses = list(requests), list(responses)
         if not requests or not responses:
-            raise ValueError("No cassettes found.")
+            raise CassetteNotFoundError("No cassettes found.")
         return requests, responses
 
 
-# pylint: disable=too-many-arguments
 def use_cassette(
     default_cassette: str,
     vcr_cassette_dir: str,
@@ -70,7 +76,11 @@ def use_cassette(
         except OSError:
             pass
         record_mode = "new_episodes"
-    vcr = VCR(path_transformer=path_transformer, cassette_library_dir=vcr_cassette_dir, record_mode=record_mode)
+    vcr = VCR(
+        path_transformer=path_transformer,
+        cassette_library_dir=vcr_cassette_dir,
+        record_mode=record_mode,
+    )
 
     def extra_path_transformer(path: str) -> str:
         """Paths in extras can be handled as relative and as absolute.
